@@ -2,7 +2,11 @@
 # test.pl
 #
 
-use Env::Array qw(PATH :);
+use Env qw(PATH);
+
+#use Env::Array { DEBUG => 1 }, qw(PATH ;); # For Win32.
+use Env::Array { DEBUG => 0 }, qw(PATH :); # For Unix/Linux.
+
 
 #
 # unique()
@@ -58,7 +62,19 @@ sub unique2
 	return @temp;
 }
 
-print "Raw \@PATH:n    ";
+print "\n";
+
+print "Raw \$PATH:\n    $PATH\n";
+print "\n";
+
+#print "Underlying object (class '", ref $path_obj, "'):\n";
+#my $path_obj = tied @PATH;
+#foreach (sort keys %$path_obj) {
+#	print "    $_ => '", $path_obj->{$_}, "'\n";
+#}
+#print "\n";
+
+print "Raw \@PATH:\n    ";
 print join("\n    ", @PATH), "\n";
 print "\n";
 
